@@ -14,6 +14,9 @@
 # limitations under the License.
 
 
+# CAM签名/鉴权错误。
+AUTHFAILURE = 'AuthFailure'
+
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
@@ -44,6 +47,9 @@ FAILEDOPERATION_RULEALREADYDISABLED = 'FailedOperation.RuleAlreadyDisabled'
 # 该规则已被启用。
 FAILEDOPERATION_RULEALREADYENABLED = 'FailedOperation.RuleAlreadyEnabled'
 
+# 部分产品已经被绑定。
+FAILEDOPERATION_SOMEPRODUCTISALREADYBINDED = 'FailedOperation.SomeProductIsAlreadyBinded'
+
 # 超过时间。
 FAILEDOPERATION_TIMEOUT = 'FailedOperation.Timeout'
 
@@ -62,6 +68,9 @@ INTERNALERROR_INTERNALSERVEREXCEPTION = 'InternalError.InternalServerException'
 # 内部DB错误。
 INTERNALERROR_INTERNALSERVEREXCEPTIONDB = 'InternalError.InternalServerExceptionDB'
 
+# 调用超时。
+INTERNALERROR_TIMEOUT = 'InternalError.Timeout'
+
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
 
@@ -71,6 +80,9 @@ INVALIDPARAMETER_ACTIONINPUTPARAMSINVALID = 'InvalidParameter.ActionInputParamsI
 # 固件已存在。
 INVALIDPARAMETER_FIRMWAREALREADYEXIST = 'InvalidParameter.FirmwareAlreadyExist'
 
+# 产品不是网关类型，无法绑定子产品。
+INVALIDPARAMETER_PRODUCTISNOTGATEWAY = 'InvalidParameter.ProductIsNotGateway'
+
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
@@ -101,6 +113,12 @@ INVALIDPARAMETERVALUE_CHECKFORWARDURLFAIL = 'InvalidParameterValue.CheckForwardU
 # 创建的设备名已存在。
 INVALIDPARAMETERVALUE_DEVICEALREADYEXIST = 'InvalidParameterValue.DeviceAlreadyExist'
 
+# 设备未绑定任何网关设备。
+INVALIDPARAMETERVALUE_DEVICEHASNOTBINDGATEWAY = 'InvalidParameterValue.DeviceHasNotBindGateway'
+
+# 设备不是网关类型。
+INVALIDPARAMETERVALUE_DEVICEISNOTGATEWAY = 'InvalidParameterValue.DeviceIsNotGateway'
+
 # 设备名称非法。
 INVALIDPARAMETERVALUE_DEVICENAMEINVALID = 'InvalidParameterValue.DeviceNameInvalid'
 
@@ -191,6 +209,9 @@ INVALIDPARAMETERVALUE_PRODUCTALREADYEXIST = 'InvalidParameterValue.ProductAlread
 # 产品ID非法。
 INVALIDPARAMETERVALUE_PRODUCTIDINVALID = 'InvalidParameterValue.ProductIDInvalid'
 
+# 产品不是网关类型，无法绑定子产品。
+INVALIDPARAMETERVALUE_PRODUCTISNOTGATEWAY = 'InvalidParameterValue.ProductIsNotGateway'
+
 # 产品参数错误。
 INVALIDPARAMETERVALUE_PRODUCTPARMSERROR = 'InvalidParameterValue.ProductParmsError'
 
@@ -233,6 +254,9 @@ LIMITEXCEEDED_BATCHPRODUCTIONEXCEEDLIMIT = 'LimitExceeded.BatchProductionExceedL
 # 量产为空。
 LIMITEXCEEDED_BATCHPRODUCTIONNULL = 'LimitExceeded.BatchProductionNull'
 
+# 绑定的产品数量超过限制。
+LIMITEXCEEDED_BINDPRODUCTSEXCEEDLIMIT = 'LimitExceeded.BindProductsExceedLimit'
+
 # 设备数量超过限制。
 LIMITEXCEEDED_DEVICEEXCEEDLIMIT = 'LimitExceeded.DeviceExceedLimit'
 
@@ -257,6 +281,9 @@ LIMITEXCEEDED_STUDIOPRODUCTEXCEEDLIMIT = 'LimitExceeded.StudioProductExceedLimit
 # 物模型超出限制。
 LIMITEXCEEDED_THINGMODELEXCEEDLIMIT = 'LimitExceeded.ThingModelExceedLimit'
 
+# Topic数量超出限制。
+LIMITEXCEEDED_TOPICPOLICYEXCEEDLIMIT = 'LimitExceeded.TopicPolicyExceedLimit'
+
 # 物模型事件 Type 错误。
 MISSINGPARAMETER_MODELDEFINEEVENTTYPEERROR = 'MissingParameter.ModelDefineEventTypeError'
 
@@ -392,6 +419,9 @@ UNSUPPORTEDOPERATION_DEVICEOTATASKINPROGRESS = 'UnsupportedOperation.DeviceOtaTa
 # 产品下还存在未删除的设备。
 UNSUPPORTEDOPERATION_DEVICESEXISTUNDERPRODUCT = 'UnsupportedOperation.DevicesExistUnderProduct'
 
+# 网关产品下存在设备绑定了子设备。
+UNSUPPORTEDOPERATION_EXISTBINDEDDEVICESUNDERGATEWAYPRODUCT = 'UnsupportedOperation.ExistBindedDevicesUnderGatewayProduct'
+
 # 存在重复围栏。
 UNSUPPORTEDOPERATION_FENCEDUPKEYEXIST = 'UnsupportedOperation.FenceDupKeyExist'
 
@@ -434,6 +464,9 @@ UNSUPPORTEDOPERATION_PROJECTDUPKEYEXIST = 'UnsupportedOperation.ProjectDupKeyExi
 # 存在重复位置空间。
 UNSUPPORTEDOPERATION_SPACEDUPKEYEXIST = 'UnsupportedOperation.SpaceDupKeyExist'
 
+# 人员库名称已存在。
+UNSUPPORTEDOPERATION_STAFFPOOLDUPNAMEEXIST = 'UnsupportedOperation.StaffPoolDupNameExist'
+
 # LoRa频点还被节点或网关使用。
 UNSUPPORTEDOPERATION_STUDIOLORAFREQINUSED = 'UnsupportedOperation.StudioLoRaFreqInUsed'
 
