@@ -17,6 +17,9 @@
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
+# 子账户RBAC权限不足。
+FAILEDOPERATION_RBACFORBIDDEN = 'FailedOperation.RBACForbidden'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -71,6 +74,9 @@ INTERNALERROR_COMPONENTCLIENTHTTP = 'InternalError.ComponentClientHttp'
 # 请求(http请求)其他云服务失败。
 INTERNALERROR_COMPONENTCLINETHTTP = 'InternalError.ComponentClinetHttp'
 
+# 容器未找到。
+INTERNALERROR_CONTAINERNOTFOUND = 'InternalError.ContainerNotFound'
+
 # 创建集群失败。
 INTERNALERROR_CREATEMASTERFAILED = 'InternalError.CreateMasterFailed'
 
@@ -83,6 +89,9 @@ INTERNALERROR_CVMNOTFOUND = 'InternalError.CvmNotFound'
 # 存在云服务器在CVM侧查询不到。
 INTERNALERROR_CVMNUMBERNOTMATCH = 'InternalError.CvmNumberNotMatch'
 
+# cvm状态不正常。
+INTERNALERROR_CVMSTATUS = 'InternalError.CvmStatus'
+
 # db错误。
 INTERNALERROR_DB = 'InternalError.Db'
 
@@ -236,6 +245,9 @@ INVALIDPARAMETER_CLUSTERNOTFOUND = 'InvalidParameter.ClusterNotFound'
 # 下一跳地址已关联CIDR。
 INVALIDPARAMETER_GATEWAYALREADYASSOCIATEDCIDR = 'InvalidParameter.GatewayAlreadyAssociatedCidr'
 
+# 无效的私有CIDR网段。
+INVALIDPARAMETER_INVALIDPRIVATENETWORKCIDR = 'InvalidParameter.InvalidPrivateNetworkCIDR'
+
 # 参数错误。
 INVALIDPARAMETER_PARAM = 'InvalidParameter.Param'
 
@@ -266,6 +278,9 @@ OPERATIONDENIED_CLUSTERINDELETIONPROTECTION = 'OperationDenied.ClusterInDeletion
 # 资源被占用。
 RESOURCEINUSE = 'ResourceInUse'
 
+# 资源不足。
+RESOURCEINSUFFICIENT = 'ResourceInsufficient'
+
 # 资源不存在。
 RESOURCENOTFOUND = 'ResourceNotFound'
 
@@ -290,6 +305,12 @@ RESOURCEUNAVAILABLE = 'ResourceUnavailable'
 # 集群状态不支持该操作。
 RESOURCEUNAVAILABLE_CLUSTERSTATE = 'ResourceUnavailable.ClusterState'
 
+# Eks Container Instance状态不支持改操作。
+RESOURCEUNAVAILABLE_EKSCONTAINERSTATUS = 'ResourceUnavailable.EksContainerStatus'
+
+# 资源售罄。
+RESOURCESSOLDOUT = 'ResourcesSoldOut'
+
 # 未授权操作。
 UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
 
