@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -41,7 +41,7 @@ class TmsClient(AbstractClient):
         - 支持在审核文本内容时同时关联账号或设备信息，可识别违规风险账号或设备。
 
         ### 接口调用说明：
-        - 文本文件大小支持：文本原文长度不能超过**15000字节或5000个汉字**（以先达到者为准）；
+        - 文本内容大小支持：文本原文长度不能超过unicode编码长度10000个字符；
         - 文本审核语言支持：目前支持中文、英文、阿拉伯数字的检测；
         - 默认接口请求频率限制：**1000次/秒**，超过该频率限制则接口会报错。
 
